FitzHugh Nagumo Model of Locus Coeruleus (Gilzenrat et al., 2002)
=================================================================

This implements a model of Locus Coeruleus / Norepinephrine (LC/NE) function described in `Gilzenrat et al. (2002)
<http://www.sciencedirect.com/science/article/pii/S0893608002000552?via%3Dihub>`_, used to simulate behavioral
and electrophysiological data (from LC recordings) in non-human primates.

The plots below were generated by PsyNeuLink (left) and the original MATLAB code used by Gilzenrat et al. (right). For a
clearer comparison, we've plotted the target unit, distraction unit, and response unit outputs as well as the h(v) and u
values produced by the LC in each figure, all *without noise*.

.. _Gilzenrat_PsyNeuLink_Fig:

.. figure:: _static/gilzenrat_psyneulink.svg
   :figwidth: 45 %
   :align: left
   :alt: Gilzenrat et al. 2002 plot produced by PsyNeuLink

.. _Gilzenrat_MATLAB_Fig:

.. figure:: _static/gilzenrat_matlab.svg
   :figwidth: 45 %
   :align: left
   :alt: Gilzenrat et al. 2002 plot produced by MATLAB


Similar plots *with noise* were included in the original
`Gilzenrat et al. (2002) <http://www.sciencedirect.com/science/article/pii/S0893608002000552?via%3Dihub>`_ paper in
figures 4A and 5A.

The `FitzHughNagumoIntegrator <FitzHughNagumoIntegrator>` function documentation includes details on how to tailor
the PsyNeuLink FitzHughNagumo implementation to the equations (6, 7, and 8) in Gilzenrat et al. 2002.


Script: :download:`Download GilzenratModel.py <../../psyneulink/library/models/GilzenratModel.py>`
